==> tbb40_20111130oss_src.tgz: tbb40_20111130oss/examples/parallel_for/tachyon/src/render.cpp <==
/*
    Copyright 2005-2011 Intel Corporation.  All Rights Reserved.

    This file is part of Threading Building Blocks.

    Threading Building Blocks is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    version 2 as published by the Free Software Foundation.

    Threading Building Blocks is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Threading Building Blocks; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    As a special exception, you may use this file as part of a free software
    library without restriction.  Specifically, if other files instantiate
    templates or use macros or inline functions from this file, or you compile
    this file and link it with other files to produce an executable, this
    file does not by itself cause the resulting executable to be covered by
    the GNU General Public License.  This exception does not however
    invalidate any other reasons why the executable file might be covered by
    the GNU General Public License.
*/

/*
    The original source for this example is
    Copyright (c) 1994-2008 John E. Stone
    All rights reserved.

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
    3. The name of the author may not be used to endorse or promote products
       derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
    OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
    HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
    OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
    SUCH DAMAGE.
*/

/* 
 * render.c - This file contains the main program and driver for the raytracer.
 *
 *  $Id: render.cpp,v 1.5 2007-02-22 18:17:51 amalakho Exp $
 */

#include "machine.h"
#include "types.h"
#include "macros.h"
#include "tgafile.h"
#include "trace.h"
#include "render.h"
#include "util.h"
#include "light.h"
#include "global.h"
#include "ui.h"
#include "tachyon_video.h"
#include "objbound.h"
#include "grid.h"

/* how many pieces to divide each scanline into */
#define NUMHORZDIV 1  

void renderscene(scenedef scene) {
  //char msgtxt[2048];
  //void * outfile;
  /* Grid based accerlation scheme */
  if (scene.boundmode == RT_BOUNDING_ENABLED) 
    engrid_scene(&rootobj); /* grid */
  /* Not used now
  if (scene.verbosemode) { 
    sprintf(msgtxt, "Opening %s for output.", scene.outfilename); 
    rt_ui_message(MSG_0, msgtxt);
  }

  createtgafile(scene.outfilename,  
                  (unsigned short) scene.hres, 
                  (unsigned short) scene.vres);
  outfile = opentgafile(scene.outfilename);
  */

  trace_region (scene, 0/*outfile*/, 0, 0, scene.hres, scene.vres);
  //fclose((FILE *)outfile);
} /* end of renderscene() */

==> tbb43_20140724oss_src.tgz: tbb43_20140724oss/examples/parallel_for/tachyon/src/render.cpp <==
/*
    Copyright 2005-2014 Intel Corporation.  All Rights Reserved.

    This file is part of Threading Building Blocks. Threading Building Blocks is free software;
    you can redistribute it and/or modify it under the terms of the GNU General Public License
    version 2  as  published  by  the  Free Software Foundation.  Threading Building Blocks is
    distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See  the GNU General Public License for more details.   You should have received a copy of
    the  GNU General Public License along with Threading Building Blocks; if not, write to the
    Free Software Foundation, Inc.,  51 Franklin St,  Fifth Floor,  Boston,  MA 02110-1301 USA

    As a special exception,  you may use this file  as part of a free software library without
    restriction.  Specifically,  if other files instantiate templates  or use macros or inline
    functions from this file, or you compile this file and link it with other files to produce
    an executable,  this file does not by itself cause the resulting executable to be covered
    by the GNU General Public License. This exception does not however invalidate any other
    reasons why the executable file might be covered by the GNU General Public License.
*/

/*
    The original source for this example is
    Copyright (c) 1994-2008 John E. Stone
    All rights reserved.

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
    3. The name of the author may not be used to endorse or promote products
       derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
    OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
    HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
    OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
    SUCH DAMAGE.
*/

/* 
 * render.cpp - This file contains the main program and driver for the raytracer.
 */

#include "machine.h"
#include "types.h"
#include "macros.h"
#include "tgafile.h"
#include "trace.h"
#include "render.h"
#include "util.h"
#include "light.h"
#include "global.h"
#include "ui.h"
#include "tachyon_video.h"
#include "objbound.h"
#include "grid.h"

/* how many pieces to divide each scanline into */
#define NUMHORZDIV 1  

void renderscene(scenedef scene) {
  //char msgtxt[2048];
  //void * outfile;
  /* Grid based accerlation scheme */
  if (scene.boundmode == RT_BOUNDING_ENABLED) 
    engrid_scene(&rootobj); /* grid */
  /* Not used now
  if (scene.verbosemode) { 
    sprintf(msgtxt, "Opening %s for output.", scene.outfilename); 
    rt_ui_message(MSG_0, msgtxt);
  }

  createtgafile(scene.outfilename,  
                  (unsigned short) scene.hres, 
                  (unsigned short) scene.vres);
  outfile = opentgafile(scene.outfilename);
  */

  trace_region (scene, 0/*outfile*/, 0, 0, scene.hres, scene.vres);
  //fclose((FILE *)outfile);
} /* end of renderscene() */
